@@ -71,6 +71,8 @@ class AutoLogin_Container
      */
     var $prop;
 
+    var $pwdlockout;
+
     /**
      * エラーメッセージ
      * @var array
@@ -181,7 +183,7 @@ class AutoLogin_Container
     }
     // }}}
 
-    function getTenants()
+    function getTenants($tenant = null)
     {
     }
 
@@ -218,6 +220,10 @@ class AutoLogin_Container
     }
     // }}}
 
+    function deletePassword($app)
+    {
+    }
+
     // {{{ getPwdChangedTime()
     /**
      *  パスワード変更時間を取得する
@@ -683,10 +689,10 @@ class AutoLogin_Container
      *
      *  @access public
      *  @param  string   シークレット
-     *  @param  string   アプリケーション
+     *  @param  string   PIN
      *  @return mixed    true:正常終了 PEAR_Error:エラー
      */
-    function setSecret($secret, $app)
+    function setSecret($secret, $pin)
     {
     }
     // }}}
